powered by
Returns the value when the coordinates of ESPG:4326 given to the input are replaced with those of the Japan Plane Rectangular CS.
st_nearest_jgd2011(geometry)st_detect_jgd2011(geometry)
st_detect_jgd2011(geometry)
geometry (POINT, EPSG:4326)
numeric vector
st_nearest_jgd2011(): It returns the coordinate system closest to the given ground object. This is valid even when the coordinates are at sea.
st_nearest_jgd2011()
st_detect_jgd2011(): Identify the coordinate system in which the given object is located.
st_detect_jgd2011()
https://www.gsi.go.jp/LAW/heimencho.html
# NOT RUN { require("sf") p <- st_sfc(sf::st_point(c(140.77, 36.8)), crs = 4326) st_nearest_jgd2011(p) st_detect_jgd2011(p) st_detect_jgd2011(st_sfc(sf::st_point(c(140.73, 36.8)), crs = 4326)) # }
Run the code above in your browser using DataLab